.. _install-plugin-registry:

===============
Plugin Registry
===============

.. note::

   Currently, Horizon plugins are responsible for their own compatibility.
   Check the individual repos for information on support.

.. list-table::
   :header-rows: 1
   :widths: 20 40 40

   * - Plugin
     - URL
     - Bug Tracker
   * - BGPVPN Dashboard
     - https://github.com/openstack/networking-bgpvpn
     - https://launchpad.net/bgpvpn
   * - Blazar Dashboard
     - https://github.com/openstack/blazar-dashboard
     - https://launchpad.net/blazar
   * - Cloudkitty Dashboard
     - https://github.com/openstack/cloudkitty-dashboard
     - https://launchpad.net/cloudkitty
   * - Congress Dashboard
     - https://github.com/openstack/congress-dashboard
     - https://launchpad.net/congress
   * - Designate Dashboard
     - https://github.com/openstack/designate-dashboard
     - https://launchpad.net/designate-dashboard
   * - Group Based Policy UI
     - https://github.com/openstack/group-based-policy-ui
     - https://launchpad.net/group-based-policy-ui
   * - Freezer Web UI
     - https://github.com/openstack/freezer-web-ui
     - https://launchpad.net/freezer
   * - Heat Dashboard
     - https://github.com/openstack/heat-dashboard
     - https://storyboard.openstack.org/#!/project/992
   * - Ironic UI
     - https://github.com/openstack/ironic-ui
     - https://launchpad.net/ironic-ui
   * - Karbor Dashboard
     - https://github.com/openstack/karbor-dashboard
     - https://launchpad.net/karbor-dashboard
   * - Magnum UI
     - https://github.com/openstack/magnum-ui
     - https://launchpad.net/magnum-ui
   * - Manila UI
     - https://github.com/openstack/manila-ui
     - https://launchpad.net/manila-ui
   * - Mistral Dashboard
     - https://github.com/openstack/mistral-dashboard
     - https://launchpad.net/mistral
   * - Monasca UI
     - https://github.com/openstack/monasca-ui
     - https://launchpad.net/monasca
   * - Murano Dashboard
     - https://github.com/openstack/murano-dashboard
     - https://launchpad.net/murano
   * - Neutron FWaaS Dashboard
     - https://github.com/openstack/neutron-fwaas-dashboard
     - https://launchpad.net/neutron-fwaas-dashboard
   * - Neutron LBaaS Dashboard
     - https://github.com/openstack/neutron-lbaas-dashboard
     - https://storyboard.openstack.org/#!/project/907
   * - Neutron VPNaaS Dashboard
     - https://github.com/openstack/neutron-vpnaas-dashboard
     - https://launchpad.net/neutron-vpnaas-dashboard
   * - Octavia Dashboard
     - https://github.com/openstack/octavia-dashboard
     - https://storyboard.openstack.org/#!/project/909
   * - Sahara Dashboard
     - https://github.com/openstack/sahara-dashboard
     - https://storyboard.openstack.org/#!/project/936
   * - Searchlight UI
     - https://github.com/openstack/searchlight-ui
     - https://launchpad.net/searchlight
   * - Senlin Dashboard
     - https://github.com/openstack/senlin-dashboard
     - https://launchpad.net/senlin-dashboard
   * - Solum Dashboard
     - https://github.com/openstack/solum-dashboard
     - https://launchpad.net/solum
   * - Tacker UI
     - https://github.com/openstack/tacker-horizon
     - https://launchpad.net/tacker
   * - TripleO UI
     - https://github.com/openstack/tripleo-ui/
     - https://launchpad.net/tripleo
   * - Trove Dashboard
     - https://github.com/openstack/trove-dashboard
     - https://launchpad.net/trove-dashboard
   * - Vitrage Dashboard
     - https://github.com/openstack/vitrage-dashboard
     - https://launchpad.net/vitrage-dashboard
   * - Watcher Dashboard
     - https://github.com/openstack/watcher-dashboard
     - https://launchpad.net/watcher-dashboard
   * - Zaqar UI
     - https://github.com/openstack/zaqar-ui
     - https://launchpad.net/zaqar-ui
   * - Zun UI
     - https://github.com/openstack/zun-ui
     - https://launchpad.net/zun-ui
